@@ -1,26 +1,24 @@
 package Code::TidyAll::Plugin::PodTidy;
 BEGIN {
-  $Code::TidyAll::Plugin::PodTidy::VERSION = '0.07';
+  $Code::TidyAll::Plugin::PodTidy::VERSION = '0.08';
 }
 use Capture::Tiny qw(capture_merged);
-use Hash::MoreUtils qw(slice_exists);
 use Pod::Tidy;
-use strict;
-use warnings;
-use base qw(Code::TidyAll::Plugin);
+use Moo;
+extends 'Code::TidyAll::Plugin';
+
+has 'columns' => ( is => 'ro' );
 
 sub transform_file {
     my ( $self, $file ) = @_;
-    my $options = $self->options;
 
-    my %params = slice_exists( $self->options, qw(columns) );
     my $output = capture_merged {
         Pod::Tidy::tidy_files(
-            %params,
             files    => [$file],
             inplace  => 1,
             nobackup => 1,
             verbose  => 1,
+            ( $self->columns ? ( columns => $self->columns ) : () ),
         );
     };
     die $output if $output =~ /\S/ && $output !~ /does not contain Pod/;
@@ -38,23 +36,33 @@ Code::TidyAll::Plugin::PodTidy - use podtidy with tidyall
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
-   # In tidyall.ini:
+   In tidyall.ini:
 
    [PodTidy]
-   argv = --column=90
    select = lib/**/*.{pm,pod}
+   columns = 90
 
-=head1 OPTIONS
+=head1 DESCRIPTION
+
+Runs L<podtidy|podtidy>, which will tidy the POD in your Perl or POD-only file.
+
+=head1 INSTALLATION
+
+Install podtidy from CPAN.
+
+    cpanm podtidy
+
+=head1 CONFIGURATION
 
 =over
 
-=item argv
+=item columns
 
-Arguments to pass to podtidy.
+Number of columns per line
 
 =back
 
