@@ -1,6 +1,6 @@
 package Code::TidyAll::SVN::Precommit;
 BEGIN {
-  $Code::TidyAll::SVN::Precommit::VERSION = '0.07';
+  $Code::TidyAll::SVN::Precommit::VERSION = '0.08';
 }
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
@@ -105,7 +105,7 @@ sub check {
                     "%d file%s did not pass tidyall check",
                     $error_count, $error_count > 1 ? "s" : ""
                 ),
-                map { join( ": ", $_->path, $_->msg ) } @error_results
+                map { join( ": ", $_->path, $_->error ) } @error_results
             );
         }
     }
@@ -169,7 +169,7 @@ to be tidyall'd
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -226,7 +226,7 @@ the first configuration file it finds.
 
 By default, if C<tidyall.ini> cannot be found, or if a runtime error occurs, a
 warning is logged (see L</LOGGING> below) but the commit is allowed to proceed.
- This is so that unexpected problems do not prevent valid commits.
+This is so that unexpected problems do not prevent valid commits.
 
 Passes mode = "commit" by default; see L<modes|tidyall/MODES>.
 
