@@ -1,15 +1,16 @@
 package Code::TidyAll::Test::Plugin::RepeatFoo;
 BEGIN {
-  $Code::TidyAll::Test::Plugin::RepeatFoo::VERSION = '0.07';
+  $Code::TidyAll::Test::Plugin::RepeatFoo::VERSION = '0.08';
 }
 use Code::TidyAll::Util qw(read_file write_file);
-use base qw(Code::TidyAll::Plugin);
-use strict;
-use warnings;
+use Moo;
+extends 'Code::TidyAll::Plugin';
+
+has 'times' => ( is => 'ro' );
 
 sub transform_source {
     my ( $self, $source ) = @_;
-    my $times = $self->options->{times} || die "no times specified";
+    my $times = $self->times || die "no times specified";
     return $source x $times;
 }
 
