@@ -1,11 +1,10 @@
 package Code::TidyAll::Test::Plugin::ReverseFoo;
 BEGIN {
-  $Code::TidyAll::Test::Plugin::ReverseFoo::VERSION = '0.07';
+  $Code::TidyAll::Test::Plugin::ReverseFoo::VERSION = '0.08';
 }
 use Code::TidyAll::Util qw(read_file write_file);
-use base qw(Code::TidyAll::Plugin);
-use strict;
-use warnings;
+use Moo;
+extends 'Code::TidyAll::Plugin';
 
 sub transform_file {
     my ( $self, $file ) = @_;
